@@ -7,22 +7,25 @@
 #
 # @author  Tim Santor  <tsantor@xstudios.agency>
 
-"""Helps outputting log messages to the console."""
-
-# Prevent compatibility regressions
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
+"""Ouptuts formatted, colored log messages to the console."""
 
 # -----------------------------------------------------------------------------
 
-import platform
+from __future__ import absolute_import, print_function, unicode_literals
+
+import codecs
+import sys
 
-# 3rd Party
-from bashutils.bashutils import get_os
-from bashutils.colors import color_text
 from six.moves import input
 
+from .bashutils import get_os
+from .colors import color_text
+
+# Use consistent encoding for terminal?
+# http://chase-seibert.github.io/blog/2014/01/12/python-unicode-console-output.html
+sys.stdout = codecs.getwriter('utf8')(sys.stdout)
+sys.stderr = codecs.getwriter('utf8')(sys.stderr)
+
 # -----------------------------------------------------------------------------
 # User feedback
 # -----------------------------------------------------------------------------
@@ -30,18 +33,25 @@ from six.moves import input
 
 def divline():
     """Prints a divider line."""
-    print("-"*80)
+    print('-' * 80)
 
 
 def header(string, logger=None):
     """Prints a header."""
     if logger:
         logger.info(string)
+    value = color_text('==> ', 'green') + color_text(string, 'white')
+    print(value)
+    return value
 
-    if get_os() == 'Windows':
-        print('==> ' + string)
-    else:
-        print(color_text('==> ', 'green') + color_text(string, 'white'))
+
+def subheader(string, logger=None):
+    """Prints a subheader."""
+    if logger:
+        logger.info(string)
+    value = color_text('==> ', 'blue') + string
+    print(value)
+    return value
 
 
 def success(string, logger=None):
@@ -49,9 +59,11 @@ def success(string, logger=None):
     if logger:
         logger.info(string)
     if get_os() == 'Windows':
-        print('[+] ' + string)
+        value = '[+] ' + string
     else:
-        print(color_text('[✓] ', 'green') + string)
+        value = color_text('[✓] ', 'green') + string
+    print(value)
+    return value
 
 
 def error(string, logger=None):
@@ -59,9 +71,11 @@ def error(string, logger=None):
     if logger:
         logger.error(string)
     if get_os() == 'Windows':
-        print('[x] ' + string)
+        value = '[x] ' + string
     else:
-        print(color_text('[✗] ', 'magenta') + string)
+        value = color_text('[✗] ', 'red') + string
+    print(value)
+    return value
 
 
 def warning(string, logger=None):
@@ -69,26 +83,20 @@ def warning(string, logger=None):
     if logger:
         logger.warning(string)
     if get_os() == 'Windows':
-        print('[!] ' + string)
+        value = '[!] ' + string
     else:
-        print(color_text('[!] ', 'yellow') + string)
+        value = color_text('[!] ', 'yellow') + string
+    print(value)
+    return value
 
 
 def info(string, logger=None):
     """Prints a info message."""
     if logger:
         logger.info(string)
-    if get_os() == 'Windows':
-        print('[i] ' + string)
-    else:
-        print(color_text('[i] ', 'cyan') + string)
-
-
-def declined(string):
-    """Prints a declined message."""
-    print(color_text('[✗] ', 'magenta') + color_text(string, 'cyan') +
-          color_text(' declined. ') + color_text('Skipping...', 'green'))
-
+    value = color_text('[i] ', 'cyan') + string
+    print(value)
+    return value
 
 # For backwards compatibility as we renamed our methods
 log_divline = divline
@@ -97,7 +105,6 @@ log_success = success
 log_error = error
 log_warning = warning
 log_info = info
-log_declined = declined
 
 # -----------------------------------------------------------------------------
 # User Input
@@ -120,9 +127,7 @@ def confirm(question):
 
     if response in ['y', 'yes']:
         return True
-    else:
-        declined(question)
-        return False
+    return False
 
 # -----------------------------------------------------------------------------
 
@@ -133,7 +138,6 @@ if __name__ == "__main__":
     error('error')
     warning('warning')
     info('info')
-    declined('something')
 
     print(prompt('What is your name?'))
 
